# Description: Performs main statistical analysis

# Clear workspace
rm(list=ls(all=TRUE))

# Load packages
library(lattice)
library(survival)
library(nlme)

# Load data, construct new features
data <- read.csv('data.csv')
setup <- read.csv('setup.csv')
data <- merge(data, setup, by.x='ID', by.y='Chamber')
data$Stack2<-factor(data$Stack)
data$censor<-ifelse(data$Bleached=='Y',0,1)
data$fraction.fed<-data$No.subchambers.fed/data$Subchambers
data$Subchambers2<-1/data$Subchambers

# LINEAR MODELS FOR AVEARGE POPULATION SIZE
#first model for average population size, stack as a random effect
mod.lme<-lme(log(mean.total)~No.subchambers.fed*Subchambers2+No.subchambers.fed+Subchambers2+Height, random=~1|Stack2,data=data);
summary(mod.lme); x11(); par(mfrow=c(2,2)); plot(mod.lme)
#second model, simple linear model
mod.lm<-lm(log(mean.total)~No.subchambers.fed*Subchambers2+No.subchambers.fed+Subchambers2+Height,data=data);
summary(mod.lm); x11(); par(mfrow=c(2,2)); plot(mod.lm)
anova(mod.lme,mod.lm)

#first model for coefficient of variation
cv.na<-(!is.na(data$cv.total))
mod2.lme<-lme(cv.total~No.subchambers.fed*Subchambers2+No.subchambers.fed+Subchambers2+Height,random=~1|Stack2,data=data,subset=cv.na);
summary(mod2.lme); x11(); par(mfrow=c(2,2)); plot(mod2.lme)
mod2.lm<-lm(cv.total~No.subchambers.fed*Subchambers2+No.subchambers.fed+Subchambers2+Height,data=data,subset=cv.na);
summary(mod2.lm); x11(); par(mfrow=c(2,2)); plot(mod2.lm)
anova(mod2.lme,mod2.lm)

#correlation
rho <- cor.test(data$mean.total, data$cv.total, method='spearman')

#Summary plots
x11()
par(mfrow=c(1,2))
boxplot(data$mean.total~data$fraction.fed, xlab='Fraction sources', ylab='Average metapopulation size')
boxplot(data$cv.total~data$fraction.fed, xlab='Fraction sources', ylab='Metapopulation CV')
savePlot('size-variability-bwplot.png',type='png')

x11(w=4, h=4)
plot(data$mean.total, data$cv.total, xlab='Average metapopulation size', ylab='Metapopulation CV')
savePlot('size-variability-scatter.png',type='png')

# Plot
H1.data <- data[data$fraction.fed==1,]
o <- order(H1.data$Days, decreasing=TRUE)
x11(w=7, h=4)
par(mfrow=c(1,2))
boxplot(H1.data$Days~H1.data$Subchambers, xlab='Number of chambers', ylab='Persistence (days)', las=1)
plot(x=H1.data$Days[o], y=seq(1:30),xlab='Persistence (days)', ylab='', type='n', yaxt='n')
for(i in 1:30) lines(x=c(0,H1.data$Days[o][i]), y=c(i,i), col=ifelse(H1.data$Subchambers[o][i]==1,'black', ifelse(H1.data$Subchambers[o][i]==2,'red','blue')), lwd=1)
for(i in 1:30)  points(x=H1.data$Days[o][i], y=i, pch=ifelse(H1.data$censor[o][i]==1,16,1) , col=ifelse(H1.data$Subchambers[o][i]==1,'black', ifelse(H1.data$Subchambers[o][i]==2,'red','blue')), lwd=1)
savePlot('persistence.png',type='png')

# Proportional hazards models
model.0<-coxph(Surv(Days,censor)~log(mean.total)+log(cv.total),data=data); summary(model.0)
check.residuals<-cox.zph(model.0,global=F);print(check.residuals);
x11(); par(mfrow=c(2,2));plot(check.residuals);plot(survfit(model.0))
savePlot('Model-0.png',type='png')


#Hypothesis 1
model.1<-coxph(Surv(Days,censor)~as.factor(Subchambers),data=data, subset=fraction.fed==1); summary(model.1)
check.residuals<-cox.zph(model.1,global=F);print(check.residuals);
x11(); par(mfrow=c(2,2));plot(check.residuals);plot(survfit(model.1))
savePlot('Model-1.png',type='png')

#Hypothesis 2
model.2<-coxph(Surv(Days,censor)~Subchambers2*No.subchambers.fed,data=data, subset=(Subchambers==2 | (Subchambers==4 & fraction.fed>0.25))); summary(model.2)
check.residuals<-cox.zph(model.2,global=F);print(check.residuals);
x11(); par(mfrow=c(2,2));plot(check.residuals);plot(survfit(model.2))
savePlot('Model-2.png',type='png')

#Hypothesis 3
model.3<-coxph(Surv(Days,censor)~as.factor(fraction.fed),data=data, subset=Subchambers==4); summary(model.3)
check.residuals<-cox.zph(model.3,global=F);print(check.residuals);
x11(); par(mfrow=c(2,2));plot(check.residuals);plot(survfit(model.3))
savePlot('Model-3.png',type='png')
#no evidence that proportional hazards assumption violated

#Extra anovas
model.4<-aov(mean.total~as.factor(fraction.fed),data=data, subset=Subchambers==4); summary(model.4)
model.5<-aov(cv.total~as.factor(fraction.fed),data=data, subset=Subchambers==4); summary(model.5)